@@ -9,9 +9,10 @@
   objDf="Objective Function DF",
   omega="Omega Matrix",
   origData="Original Data",
+  phiC="covariance matrix of each individual's eta (if present)",
   parFixed="Formatted Parameter Values for Fixed effects",
   parFixedDf="Parameter Values for Fixed Effects (data frame)",
-  parHist="Parameter History",
+  parHistData="Parameter History (including gradients)",
   scaleInfo="Scaling Information",
   shrink="Shrinkage data frame",
   table="Table Control Value",
